@@ -66,9 +66,12 @@ class GetMediaShowItemView(BrowserView):
         """
         item = self.context
         
-        if(self.isVideo(item) or item.portal_type == 'Image'):
+        if(self.isVideo(item)):
             return item.absolute_url()
         
+        if item.portal_type == 'Image':
+            return leadMedia.getURL() + '/image_large'
+        
         if item.portal_type == 'Link' and (item.remoteUrl.find("youtube.com") > -1 or item.remoteUrl.find("vimeo.com") > -1):
             return item.remoteUrl
         
